@@ -5,6 +5,7 @@ import requests
 class Mojo:
   def __init__(self, endpoint, port=3000, use_ssl=False,
                verify=True, user=None, password=None):
+    """Constructs a Mojo by connecting to a Jojo and caching its scripts"""
     self.endpoint = "http"
     if use_ssl:
       self.endpoint += "s"
@@ -19,9 +20,14 @@ class Mojo:
     else:
       self.auth = False
 
-    self.scripts = self.__get_scripts()
+    scripts = self.__get_scripts()
+    if isinstance(scripts, dict):
+      self.scripts = scripts
+    else:
+      self.scripts = {}
 
   def __call(self, path, method="GET", data=""):
+    """Makes a call to a Jojo"""
     s = requests.Session()
     headers = {
       "Content-Type" : "application/json"
@@ -42,21 +48,38 @@ class Mojo:
 
 
   def __get_scripts(self):
+      """Gets a collection of scripts that live on the Jojo"""
       resp = self.__call("/scripts", method="GET")
-      return resp.json()['scripts']
+      if resp.status_code == 200:
+        return resp.json()['scripts']
+      return resp
 
   def reload(self):
+    """Reloads the Jojo's script cache, then stashes that data in the Mojo"""
     r = self.__call("/reload", method="POST")
     self.scripts = self.__get_scripts()
 
   def get_script(self, name, use_cache=True):
+    """Gets data about a script in the Jojo, from the cache or from the Jojo"""
     if use_cache:
-      return self.scripts[name]
+      if self.scripts[name] is not None:
+        return self.scripts[name]
+      else:
+        return None
     else:
-      return self.__call("/scripts/" + name).json()['script']
+      resp = self.__call("/scripts/" + name)
+      if resp.status_code == 200:
+        self.scripts[name] = resp.json()['script']
+        return self.scripts[name]
+      else:
+        return None
 
   def run(self, name, params={}):
+    data = None
     if len(params) > 0:
       data = json.dumps(params)
-      return self.__call("/scripts/" + name, method="POST", data=data)
-    return self.__call("/scripts/" + name, method="POST")
+
+    resp = self.__call("/scripts/" + name, method="POST", data=data)
+    if resp.status_code == 200:
+      return resp.json()
+    return resp
